window.Gleam.initSearch([{"doc":"gleamyshell","title":"gleamyshell","content":"# GleamyShell\n\nGleamyShell is a cross-platform Gleam library for executing shell commands that supports multiple targets (Erlang, Deno,\nand Node.js).\n\n## When to use GleamyShell?\n\nGleamyShell provides the ability to execute shell commands on multiple targets. While this might sound amazing,\nsupporting targets with fundamentally different concurrency models and APIs shrinks the common ground significantly.\n\nIn order to keep the public API homogenous across different targets, GleamyShell only provides synchronous bindings and\na minimal API with common functionalities supported by those targets.\n\nYou should use GleamyShell if\n\n-   you need or want to support multiple targets _and/or_\n-   synchronous shell command execution is not a concern _and/or_\n-   you don&#39;t have special use cases that GleamyShell&#39;s API cannot serve.\n\n## Usage\n\n### Getting the current username\n\n```gleam\nlet result = gleamyshell.execute(&quot;whoami&quot;, [])\n\ncase result {\n  Ok(username) -&gt;\n    io.println(&quot;Hello there, &quot; &lt;&gt; string.trim(username) &lt;&gt; &quot;!&quot;)\n  Error(Failure(output, exit_code)) -&gt;\n    io.println(\n      &quot;Whoops!\\nError (&quot;\n      &lt;&gt; int.to_string(exit_code)\n      &lt;&gt; &quot;): &quot;\n      &lt;&gt; string.trim(output),\n    )\n  Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n}\n```\n\n### Getting the current working directory\n\n```gleam\ncase gleamyshell.cwd() {\n  Some(working_directory) -&gt;\n    io.println(&quot;Current working directory: &quot; &lt;&gt; working_directory)\n  None -&gt;\n    io.println(&quot;Couldn&#39;t detect the current working directory.&quot;)\n}\n```\n\n## Changelog\n\nTake a look at the [changelog](https://github.com/patrik-kuehl/gleamyshell/blob/main/CHANGELOG.md) to get an overview of\neach release and its changes.\n\n## Contribution Guidelines\n\nMore information can be found [here](https://github.com/patrik-kuehl/gleamyshell/blob/main/CONTRIBUTING.md).\n\n## License\n\nGleamyShell is licensed under the [MIT license](https://github.com/patrik-kuehl/gleamyshell/blob/main/LICENSE.md).\n","url":"index.html"},{"doc":"gleamyshell","title":"gleamyshell","content":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThis project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.2.0] - 2024-05-28\n\n### Features\n\n-   Implement Gleam os function\n-   [**breaking**] Define OsFamily and Os types and rename constructor\n-   Implement JavaScript os function\n-   Implement Elixir os function\n\n## 0.1.0 - 2024-05-26\n\n### Features\n\n-   Implement execute_in function\n-   Introduce working directory parameter in execute FFI functions\n-   Handle abort reasons\n-   Implement Gleam cwd function\n-   Implement Elixir cwd function\n-   Implement JavaScript cwd function\n-   Implement Gleam execute function\n-   Implement Elixir execute function\n-   Implement JavaScript execute function\n\n&lt;!-- generated by git-cliff --&gt;\n","url":"changelog.html"},{"doc":"gleamyshell","title":"gleamyshell","content":"# MIT License\n\nCopyright (c) 2024 Patrik Kühl\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated\ndocumentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the\nrights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit\npersons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the\nSoftware.\n\nTHE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE\nWARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR\nOTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n","url":"license.html"},{"doc":"gleamyshell","title":"AbortReason","content":"pub type AbortReason {\n  Enomem\n  Eagain\n  Enametoolong\n  Emfile\n  Enfile\n  Eacces\n  Enoent\n  OtherAbortReason(String)\n}\n Represents the reason why the execution of a command was aborted.\n\n Most of these reasons are common POSIX errors.\nEnomem\n Not enough memory.\n\nEagain\n Resource temporarily unavailable.\n\nEnametoolong\n Too long file name.\n\nEmfile\n Too many open files.\n\nEnfile\n File table overflow.\n\nEacces\n Insufficient permissions.\n\nEnoent\n No such file or directory.\n\nOtherAbortReason(String)\n An error not represented by the other options.\n\nSynonyms:\ngleamyshell.AbortReason\ngleamyshell AbortReason","url":"gleamyshell.html#AbortReason"},{"doc":"gleamyshell","title":"CommandError","content":"pub type CommandError {\n  Failure(output: String, exit_code: Int)\n  Abort(reason: AbortReason)\n}\n Represents information about why a command execution failed.\nFailure(output: String, exit_code: Int)\n The command could be executed but returned a non-zero exit code.\n\nAbort(reason: AbortReason)\n The command did not execute and instead was aborted.\n\nSynonyms:\ngleamyshell.CommandError\ngleamyshell CommandError","url":"gleamyshell.html#CommandError"},{"doc":"gleamyshell","title":"Os","content":"pub type Os {\n  Darwin\n  FreeBsd\n  OpenBsd\n  Linux\n  SunOs\n  OtherOs(String)\n}\n Represents names of operating systems.\nDarwin\n The Unix operating system used by Apple as a core for its operating systems (e.g., macOS).\n\nFreeBsd\n A free Unix-like operating system descended from AT&amp;T&#39;s UNIX.\n\nOpenBsd\n A free Unix-like operating system forked from NetBSD.\n\nLinux\n The Linux kernel is the base for many Unix-like operating systems like Debian.\n\nSunOs\n The Unix-like operating system SunOS is used as a core for other distributions like Solaris.\n\nOtherOs(String)\n An operating system not represented by the other options.\n\nSynonyms:\ngleamyshell.Os\ngleamyshell Os","url":"gleamyshell.html#Os"},{"doc":"gleamyshell","title":"OsFamily","content":"pub type OsFamily {\n  Unix(Os)\n  Windows\n}\n Represents families of operating systems.\nUnix(Os)\n The operating system is part of the Unix family.\n\nWindows\n The operating system is part of the Windows family.\n\nSynonyms:\ngleamyshell.OsFamily\ngleamyshell OsFamily","url":"gleamyshell.html#OsFamily"},{"doc":"gleamyshell","title":"cwd","content":"pub fn cwd() -&gt; Option(String)\n Returns the current working directory.\n \n This function returns an `Option` because it can fail on Unix-like systems in rare circumstances.\n \n ## Example\n \n \n case gleamyshell.cwd() {\n   Some(working_directory) -&gt;\n     io.println(&quot;Current working directory: &quot; &lt;&gt; working_directory)\n   None -&gt; io.println(&quot;Couldn&#39;t detect the current working directory.&quot;)\n }\n \nSynonyms:\ngleamyshell.cwd\ngleamyshell cwd","url":"gleamyshell.html#cwd"},{"doc":"gleamyshell","title":"execute","content":"pub fn execute(\n  command command: String,\n  args args: List(String),\n) -&gt; Result(String, CommandError)\n Executes the given command with arguments.\n\n ## Example\n \n \n let result = gleamyshell.execute(&quot;whoami&quot;, [])\n \n case result {\n   Ok(username) -&gt;\n     io.println(&quot;Hello there, &quot; &lt;&gt; string.trim(username) &lt;&gt; &quot;!&quot;)\n   Error(Failure(output, exit_code)) -&gt;\n     io.println(\n       &quot;Whoops!\\nError (&quot;\n       &lt;&gt; int.to_string(exit_code)\n       &lt;&gt; &quot;): &quot;\n       &lt;&gt; string.trim(output),\n     )\n   Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n }\n \n \n This function can also be invoked by using labelled arguments.\n \n \n let result = gleamyshell.execute(&quot;ls&quot;, args: [&quot;-la&quot;])\n let another_result = gleamyshell.execute(command: &quot;ls&quot;, args: [&quot;-la&quot;])\n \nSynonyms:\ngleamyshell.execute\ngleamyshell execute","url":"gleamyshell.html#execute"},{"doc":"gleamyshell","title":"execute_in","content":"pub fn execute_in(\n  command command: String,\n  args args: List(String),\n  working_directory working_directory: String,\n) -&gt; Result(String, CommandError)\n Executes the given command with arguments in a specified working directory.\n\n ## Example\n \n \n let result =\n   gleamyshell.execute_in(&quot;cat&quot;, [&quot;.bashrc&quot;], &quot;/home/username&quot;)\n \n case result {\n   Ok(file_content) -&gt; io.println(file_content)\n   Error(Failure(output, exit_code)) -&gt;\n     io.println(\n       &quot;Whoops!\\nError (&quot;\n       &lt;&gt; int.to_string(exit_code)\n       &lt;&gt; &quot;): &quot;\n       &lt;&gt; string.trim(output),\n     )\n   Error(Abort(_)) -&gt; io.println(&quot;Something went terribly wrong.&quot;)\n }\n \n \n This function can also be invoked by using labelled arguments.\n \n \n let result =\n   gleamyshell.execute_in(\n     &quot;ls&quot;,\n     args: [&quot;-la&quot;],\n     working_directory: &quot;/usr/bin&quot;,\n   )\n \n let another_result =\n   gleamyshell.execute_in(\n     command: &quot;ls&quot;,\n     args: [&quot;-la&quot;],\n     working_directory: &quot;/usr/bin&quot;,\n   )\n \nSynonyms:\ngleamyshell.execute_in\ngleamyshell execute_in","url":"gleamyshell.html#execute_in"},{"doc":"gleamyshell","title":"os","content":"pub fn os() -&gt; OsFamily\n Returns information about the host&#39;s operating system.\n \n This function is meant to be a quality-of-life feature where someone needs to execute different\n shell commands that differ depending on the operating system.\n \n ## Example\n \n \n case gleamyshell.os() {\n   Windows -&gt; io.println(&quot;Doing stuff on Windows.&quot;)\n   Unix(_) -&gt; io.println(&quot;Doing stuff on a Unix(-like) system.&quot;)\n }\n \nSynonyms:\ngleamyshell.os\ngleamyshell os","url":"gleamyshell.html#os"},{"doc":"gleamyshell","title":"gleamyshell","content":"","url":"gleamyshell.html"}]);